<?xml version="1.0" encoding="windows-1250"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" exclude-result-prefixes="msxsl">
<xsl:output method="html" encoding="windows-1250" media-type="text/html"/>
<xsl:template match="ps-syntax-doc">
    <html>
		<HEAD>
			<TITLE>RemObjects PascalScript - SyntaxDoc</TITLE>
			<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
      <style>
        body {font-size:x-small; font-family:'Segoe UI',Tahoma;}
      </style>
		</HEAD>
		<body>
      <h3>Keywords</h3>
      <ul>
      <xsl:for-each select="keywords/keyword">
        <li><b><xsl:value-of select="@id" /></b></li>
      </xsl:for-each>
      </ul>
      <br />

      <h3>Constants</h3>
      <ul>
      <xsl:for-each select="consts/const">
        <li><b><xsl:value-of select="@id" /></b> = <xsl:value-of select="@decl" />;</li>
      </xsl:for-each>
      </ul>

      <h3>Types</h3>
      <ul>
      <xsl:for-each select="types/type">
        <li>
          <b><xsl:value-of select="@id" /></b>
            <xsl:if test="@ancestor"> = <xsl:value-of select="@ancestor" />;</xsl:if>
            <xsl:if test="field">
              = <b>record</b><br />
              <xsl:for-each select="field">
                &#160;&#160;<xsl:value-of select="@id" />: <xsl:value-of select="@decl" />;<br />
              </xsl:for-each>
              <b>end;</b>
            </xsl:if>
            <xsl:if test="not(field)">
              <xsl:if test="@decl"> = <xsl:value-of select="@decl" />;</xsl:if>
            </xsl:if>
        </li>
      </xsl:for-each>
      </ul>

      <h3>Variables</h3>
      <ul>
      <xsl:for-each select="variables/var">
        <li><b><xsl:value-of select="@id" /></b>: <xsl:value-of select="@decl" />;</li>
      </xsl:for-each>
      </ul>

      <h3>Global objects</h3>
      <ul>
      <xsl:for-each select="objvariables/var">
        <li><b><xsl:value-of select="@id" /></b>: <xsl:value-of select="@decl" />;</li>
      </xsl:for-each>
      </ul>

      <h3>Procedures</h3>
      <ul>
      <xsl:for-each select="procedures/procedure">
        <li>procedure <b><xsl:value-of select="@id" /></b><xsl:value-of select="@decl" />;</li>
      </xsl:for-each>
      </ul>

      <h3>Functions</h3>
      <ul>
      <xsl:for-each select="functions/function">
        <li>function <b><xsl:value-of select="@id" /></b><xsl:value-of select="@decl" />;</li>
      </xsl:for-each>
      </ul>

      <h3>Classes</h3>
      <ul>
      <xsl:for-each select="classes/class">
        <li>
          <b><xsl:value-of select="@id" /></b>
            <xsl:if test="@ancestor"> = <b>class</b>(<xsl:value-of select="@ancestor" />)</xsl:if>
            <xsl:if test="not(@ancestor)"> = <b><xsl:value-of select="@decl" /></b></xsl:if>
            <xsl:if test="not(*) and not(@ancestor)">;</xsl:if>
            <xsl:if test="@ancestor or *">
              <ul>
                <xsl:apply-templates select="current()" />
              </ul>
              <b>end;</b>
            </xsl:if>
        </li>
      </xsl:for-each>
      </ul>

		</body>
	</html>
</xsl:template>

<xsl:template match="class">
  <xsl:variable name="members">
      <xsl:call-template name="imembers" >
        <xsl:with-param name="class" select="current()" />
      </xsl:call-template>
  </xsl:variable>
                <xsl:for-each select="msxsl:node-set($members)/*[not(@id = preceding-sibling::node()/@id)]">
                  <xsl:sort select="local-name()" /><xsl:sort select="@id" />
                  <li><xsl:value-of select="local-name()" />&#160;<b><xsl:value-of select="@id" /></b><xsl:value-of select="@decl" />;</li>
                </xsl:for-each>
</xsl:template>

<xsl:template name="imembers">
  <xsl:param name="class" />
  <xsl:apply-templates select="$class/*"/>
  <xsl:if test="$class/@ancestor">
    <xsl:call-template name="imembers" >
      <xsl:with-param name="class" select="//class[@id=$class/@ancestor]" />
    </xsl:call-template>
  </xsl:if>
</xsl:template>

<xsl:template match="class/*">
  <xsl:copy-of select="."/>
</xsl:template>

</xsl:stylesheet>
  